package com.yidian.shenghuoquan.newscontent.ui

import android.location.Location
import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.Toast
import com.amap.api.maps.AMap
import com.amap.api.maps.AMap.OnMyLocationChangeListener
import com.amap.api.maps.MapView
import com.amap.api.maps.model.*
import com.amap.api.services.core.AMapException
import com.amap.api.services.core.LatLonPoint
import com.amap.api.services.core.PoiItem
import com.amap.api.services.core.SuggestionCity
import com.amap.api.services.poisearch.PoiResult
import com.amap.api.services.poisearch.PoiSearch
import com.amap.api.services.poisearch.PoiSearch.OnPoiSearchListener
import com.yidian.common.base.BaseActivity
import com.yidian.shenghuoquan.newscontent.R
import com.yidian.shenghuoquan.newscontent.databinding.ActivitySelectAddressBinding
import kotlinx.android.synthetic.main.activity_select_address.*


/**
 * Author: sym
 * Date: 2021/6/24 2:10 PM
 * Describe:
 */
class SelectAddressActivity : BaseActivity<ActivitySelectAddressBinding>(), OnMyLocationChangeListener, AMap.OnMapClickListener, OnPoiSearchListener {
  private lateinit var mapView: MapView
  private var myLocationStyle: MyLocationStyle? = null
  var bitmapDescriptor: BitmapDescriptor? = null
  private var markerView: View? = null
  private var currentMarker: Marker? = null
  private var boundsBuilder: LatLngBounds.Builder? = null


  var aMap: AMap? = null
  override fun createViewBinding(): ActivitySelectAddressBinding {
    return ActivitySelectAddressBinding.inflate(layoutInflater)
  }

  override fun getXPageName(): String {
    return ""
  }

  override fun init(savedInstanceState: Bundle?) {
    super.init(savedInstanceState)
    mapView = viewBind.map
    mapView.onCreate(savedInstanceState)
    bitmapDescriptor = BitmapDescriptorFactory.fromView(markerView)
    markerView = layoutInflater.inflate(R.layout.layout_service_addr_map_marker, null)
    boundsBuilder = LatLngBounds.Builder()

    if (aMap == null) {
      aMap = mapView.map
      setUpMap()
    }

    //设置SDK 自带定位消息监听
    aMap!!.setOnMyLocationChangeListener(this)

    aMap!!.myLocationStyle = myLocationStyle!!.myLocationType(MyLocationStyle.LOCATION_TYPE_LOCATE)


    viewBind.selectAddBackBtn.setOnClickListener {
      finish()
    }
    viewBind.selectAddSearchText.setOnClickListener {
      Toast.makeText(this@SelectAddressActivity, "SelectAddressActivity", Toast.LENGTH_SHORT).show()
    }
  }

  override fun onPause() {
    super.onPause()
    viewBind.map.onPause()
  }

  override fun onResume() {
    super.onResume()
    viewBind.map.onResume()
  }

  override fun onDestroy() {
    super.onDestroy()
    viewBind.map.onDestroy();
  }

  override fun onSaveInstanceState(outState: Bundle) {
    super.onSaveInstanceState(outState)
    viewBind.map.onSaveInstanceState(outState)
  }

  /**
   * 设置一些amap的属性
   */
  private fun setUpMap() {
    // 如果要设置定位的默认状态，可以在此处进行设置
    myLocationStyle = MyLocationStyle()
    aMap!!.myLocationStyle = myLocationStyle
    aMap!!.uiSettings.isMyLocationButtonEnabled = true // 设置默认定位按钮是否显示
    aMap!!.isMyLocationEnabled = true // 设置为true表示显示定位层并可触发定位，false表示隐藏定位层并不可触发定位，默认是false
    aMap!!.setOnMapClickListener(this) // 设置点击marker事件监听器
  }

  override fun onMyLocationChange(location: Location?) {
    // 定位回调监听
    if (location != null) {
      Log.e("amap", "onMyLocationChange 定位成功， lat: " + location.getLatitude() + " lon: " + location.getLongitude())
      val bundle: Bundle = location.getExtras()
      if (bundle != null) {
        val errorCode = bundle.getInt(MyLocationStyle.ERROR_CODE)
        val errorInfo = bundle.getString(MyLocationStyle.ERROR_INFO)
        // 定位类型，可能为GPS WIFI等，具体可以参考官网的定位SDK介绍
        val locationType = bundle.getInt(MyLocationStyle.LOCATION_TYPE)

        /*
                errorCode
                errorInfo
                locationType
                */Log.e("amap", "定位信息， code: $errorCode errorInfo: $errorInfo locationType: $locationType")
      } else {
        Log.e("amap", "定位信息， bundle is null ")
      }
    } else {
      Log.e("amap", "定位失败")
    }
  }

  override fun onMapClick(latLng: LatLng?) {
    updataCurrentMarker(latLng)
  }

  private fun updataCurrentMarker(latLng: LatLng?) {
    val markerOption = MarkerOptions()
    markerOption.position(latLng)
    markerOption.icon(bitmapDescriptor)
    markerOption.anchor(0F, 1F)
    currentMarker?.remove()
    currentMarker = aMap!!.addMarker(markerOption)
    currentMarker!!.setObject(latLng)
    boundsBuilder?.include(latLng)
    queryPoi()
  }


  private fun queryPoi() {
    val latLng = currentMarker!!.getObject() as LatLng
    val typeRange = "汽车服务|汽车销售|" +
      "汽车维修|摩托车服务|餐饮服务|购物服务|生活服务|体育休闲服务|医疗保健服务|" +
      "住宿服务|风景名胜|商务住宅|政府机构及社会团体|科教文化服务|交通设施服务|" +
      "金融保险服务|公司企业|道路附属设施|地名地址信息|公共设施"

    // keyWord表示搜索字符串，第二个参数表示POI搜索类型，默认为：生活服务、餐饮服务、商务住宅
    //共分为以下20种：汽车服务|汽车销售|
    //汽车维修|摩托车服务|餐饮服务|购物服务|生活服务|体育休闲服务|医疗保健服务|
    //住宿服务|风景名胜|商务住宅|政府机构及社会团体|科教文化服务|交通设施服务|
    //金融保险服务|公司企业|道路附属设施|地名地址信息|公共设施
    //cityCode表示POI搜索区域，（这里可以传空字符串，空字符串代表全国在全国范围内进行搜索）
    val query: PoiSearch.Query = PoiSearch.Query("", typeRange, "")
    query.pageSize = 10 // 设置每页最多返回多少条poiitem

    query.pageNum = 1 //设置查第一页
    val poiSearch = PoiSearch(this, query)
    poiSearch.bound = PoiSearch.SearchBound(LatLonPoint(latLng.latitude,
      latLng.longitude), 500) //设置周边搜索的中心点以及区域

    poiSearch.setOnPoiSearchListener(this) //设置数据返回的监听器

    poiSearch.searchPOIAsyn()
  }

  override fun onPoiSearched(poiResult: PoiResult?, rCode: Int) {
    if (rCode == AMapException.CODE_AMAP_SUCCESS) {
      if (poiResult != null && poiResult.getQuery() != null) {
        // 取得搜索到的poiitems有多少页
        val poiItems: List<PoiItem> = poiResult.getPois() // 取得第一页的poiitem数据，页数从数字0开始
        val suggestionCities: List<SuggestionCity> = poiResult
          .getSearchSuggestionCitys() // 当搜索不到poiitem数据时，会返回含有搜索关键字的城市信息

        if (poiItems != null && poiItems.size > 0) {
        }
      }
    }

  }

  override fun onPoiItemSearched(p0: PoiItem?, p1: Int) {
  }

}
